<?php
/**
 * Plugin Helper File
 *
 * @package         AdminBar Docker
 * @version         2.4.1
 *
 * @author          Peter van Westen <peter@nonumber.nl>
 * @link            http://www.nonumber.nl
 * @copyright       Copyright © 2012 NoNumber All Rights Reserved
 * @license         http://www.gnu.org/licenses/gpl-2.0.html GNU/GPL
 */

defined('_JEXEC') or die;

/**
 * Plugin that docks the admin toolbars
 */
class plgSystemAdminBarDockerHelper
{
	function __construct(&$params)
	{
		$this->params = $params;
	}

	/*
	 * Place scripts and styles and load language
	 */
	function onAfterDispatch()
	{
		JHtml::_('behavior.mootools');

		$this->template = JFactory::getApplication()->getTemplate();
		if (!JFile::exists(JPATH_SITE . '/media/adminbardocker/templates/' . $this->template . '/script.js')) {
			// if template folder does not exist, fall back on default template bluestork
			$this->template = 'bluestork';
		}

		$ignorecookie = 0;
		if ($this->params->showonpopups != 1) {
			$tmpl = JFactory::getApplication()->input->get('tmpl', 'index');
			if (!in_array($tmpl, array('index', 'cpanel')) || JFactory::getApplication()->input->getInt('nn_qp', 0)) {
				if ($this->params->showonpopups == 2) {
					$this->params->dock_state = 'docked';
					$ignorecookie = 1;
				} else {
					return;
				}
			}
		}

		/* TODO: make template media files listen to template overrides */
		JFactory::getDocument()->addScript(JURI::root(true) . '/media/adminbardocker/templates/' . $this->template . '/script.js');
		JHtml::script('adminbardocker/script.min.js', false, true);
		JHtml::stylesheet('adminbardocker/style.min.css', false, true);
		JFactory::getDocument()->addStyleSheet(JURI::root(true) . '/media/adminbardocker/templates/' . $this->template . '/style.css');

		$iconset = trim($this->params->iconset);
		$img_path = '/media/adminbardocker/images/';
		if (!$iconset || !JFile::exists(JPATH_SITE . $img_path . $iconset)) {
			$iconset = 'iconset_11.png';
		}
		$css = '
			div.abd_icon div {
				background-image: url(' . JURI::root(true) . $img_path . $iconset . ');
			}
		';
		JFactory::getDocument()->addStyleDeclaration($css);

		$set_cookies = array();
		if ($this->params->dock_state == 'undocked') {
			$set_cookies[] = 'ABD_setCookie( \'abd_dock_state\', \'undocked\' );';
		}
		if ($this->params->dock_pos == 'bottom') {
			$set_cookies[] = 'ABD_setCookie( \'abd_dock_pos\', \'bottom\' );';
		}
		if ($this->params->autohide) {
			$set_cookies[] = 'ABD_setCookie( \'abd_autohide\', 1 );';
		}

		$settings_url = '';
		if (JFactory::getUser()->authorise('core.admin')) {
			$settings_url = JURI::base() . 'index.php?option=com_plugins&filter_search=adminbar%20docker';
		}
		$script = "
			var abd_top = [];
			var abd_toggle_top = [];
			var abd_toggle_bottom = [];
			var abd_bottom = [];
			var abd_settings_url = '" . $settings_url . "';
			window.addEvent( 'domready', function() {
				" . implode("\n\t\t\t\t", $set_cookies) . "
				new AdminBarDocker(
					'" . $this->template . "',
				 	[
				 		'" . addslashes(JText::_('ABD_SETTINGS')) . "',
						'" . addslashes(JText::_('ABD_UNDOCK')) . "',
						'" . addslashes(JText::_('ABD_DOCK')) . "',
						'" . addslashes(JText::_('ABD_RELOAD')) . "',
						'" . addslashes(JText::_('ABD_TO_TOP')) . "',
						'" . addslashes(JText::_('ABD_TO_BOTTOM')) . "',
						'" . addslashes(JText::_('ABD_UNDOCK_TO_TOP')) . "',
						'" . addslashes(JText::_('ABD_UNDOCK_TO_BOTTOM')) . "',
						'" . addslashes(JText::_('ABD_AUTO_HIDE')) . "',
						'" . addslashes(JText::_('ABD_NO_AUTO_HIDE')) . "',
					],
					" . $this->params->hidetopbar . ",
					" . $ignorecookie . "
				);
			});
		";
		JFactory::getDocument()->addScriptDeclaration(preg_replace("#\s+#s", ' ', $script));
	}
}
